# 简介
this code is used for my learning, 
because other wheels are not enough or perfect  
author: nwkami.   
init.py should put in a path named as your package name,and "name = "example_pkg""in it
again I move the code py into the path where init in. and in init we write "from xxx import *"  
then this version is the first usable version
README文件中有中文的时候，setup需要有特殊的设置。  
这一版我加上了  
库函数的代码我没有改
# 更新记录
~~~~~~~~~~~~~~~~~~~~
加上了matrixlizing_function函数
~~~~~~~~~~~~~~~~~~~~
~~~~~~~~~~~~~~~~~~~~
加上了get_location_by_name
~~~~~~~~~~~~~~~~~~~~
~~~~~~~~~~~~~~~~~~~~
把get_location_by_name改进了  
现在一二参数的函数都可使用
~~~~~~~~~~~~~~~~~~~~
~~~~~~~~~~~~~~~~~~~~
把readme重写了一遍
~~~~~~~~~~~~~~~~~~~~
~~~~~~~~~~~~~~~~~~~~
原来install_requires中的库可以在导入的时候同时导入  
其他库
~~~~~~~~~~~~~~~~~~~~
~~~~~~~~~~~~~~~~~~~~
增加了install_requires中的库
~~~~~~~~~~~~~~~~~~~~
~~~~~~~~~~~~~~~~~~~~
增加了cartesian_product函数
~~~~~~~~~~~~~~~~~~~~
# 该版本更新记录
~~~~~~~~~~~~~~~~~~~~
增加了shortest_path_with_inf函数
~~~~~~~~~~~~~~~~~~~~
# 函数列表
~~~~~~~~~~~~~~~~~~~~
1.calc_azimuth
2.int_matrix
3.save_variable
4.load_variable
5.ndarray2img
6.argsort_matrix
7.matrixlizing_function
8.get_location_by_name
9.cartesian_product
10.shortest_path_with_inf
~~~~~~~~~~~~~~~~~~~~

